.. gcm-filters documentation master file, created by
   sphinx-quickstart on Tue Jan 12 09:24:23 2021.
   You can adapt this file completely to your liking, but it should at least
   contain the root `toctree` directive.

``model_catalogs``
==================

.. toctree::
   :maxdepth: 2
   :hidden:
   :caption: Documentation

   demo
   subsetting
   paths
   standard_names
   update_boundaries
   whats_new
   api
   GitHub repository <https://github.com/NOAA-ORR-ERD/model_catalogs>
